/*
 NYTimes API Classes
 February, 2009
 blprnt@blprnt.com
 NOTE: Make sure you enter your NYTimes Article Search API on the TimesArticleSearch tab.
 */
import processing.opengl.*;
import org.json.*;
import java.util.ArrayList;

PFont font1 = createFont("Arial", 16); 
PFont font2 = createFont("Arial", 20);
int[][] transactionsPerMonth = new int[6][12];
int[][] articlesPerMonth = new int[6][12];
int[][] frontPagePerMonth = new int[6][12];
String[][] articleTitles = new String[6][12];
String[][] articlePopularTitles = new String[6][12];

boolean showGrid = true;
boolean leftMouseClicked = false;
boolean rightMouseClicked = false;
boolean addColor = false;
int padding = 30;
float horizontalGridDivisions = 12;
float verticalGridDivisions = 8;
float horizontalSquareSize;
float verticalSquareSize;

float SPL_Multiplier = 0.5;
float NYT_Multiplier = 1.25;
float SPL_Circle_Multiplier = 1.0;
float NYT_Circle_Multiplier = 2.0;

void setup() {
  size(960, 640); //size of the sketch window
  horizontalSquareSize = width/horizontalGridDivisions;
  verticalSquareSize = height/verticalGridDivisions;
  colorMode(HSB, 360, 100, 100,100);  
  smooth();
  
  //import the data from our text file 
  String savedData[] = loadStrings("savedData.txt");
  println("QUERY: " + savedData[0]);
  for (int i=1; i < savedData.length; i++) {
    String temp[] = split(savedData[i], ",");
    transactionsPerMonth[Integer.parseInt(temp[0])-2006][Integer.parseInt(temp[1])-1] = Integer.parseInt(temp[2]);
  } 
    
  //ny times api stuff
  for(int i = 0;i<5;i++){      // years
    for(int j = 0;j<12;j++){    // months
      TimesArticleSearch s = new TimesArticleSearch();
      s.addQueries("Greece");
//      s.addQueries("finance");
//      s.addQueries("real");
//      s.addQueries("estate");
      s.addFacets("page_facet");
      s.addFacetQuery("publication_year", "" + (2006+i));
      //we have to turn the month into a string like "07" which is kind of annoying. 
      String m = (j + 1 < 10) ? ("0" + str(int(j) + 1)):str(j + 1);
      s.addFacetQuery("publication_month", m);
      TimesArticleSearchResult r = s.doSearch();
      //TimesFacetObject[] pageFacets = r.getFacetList("page_facet");
      TimesFacetObject[] pageFacets = r.getFacetList("page_facet");
      println ("There were " + r.total + " articles.");
      println ("There were " + pageFacets[0].count + " articles on the front page");
      println ("The first article was titled: " + r.results[0].title);
      articlesPerMonth[i][j] = r.total;
      articleTitles[i][j] = r.results[0].title;
      frontPagePerMonth[i][j] = pageFacets[0].count;
    }
  }

}

void draw(){
  background(195);
  if(showGrid){drawGrid();}
  
  float circleDivision = (PI*2.0)/60.0;
//  float horizontalDivision = (width/60.0;//(horizontalSquareSize*7.0+padding)/60.0;
  float horizontalDivision = (width-(padding*2))/60.0;//(horizontalSquareSize*7.0+padding)/60.0;
  
  for(int i = 0;i<5;i++){
    fill(0,100,50,100);
  //  strokeWeight(0.0);
    for(int j = 0;j<12;j++){
    
       //SPL transactions line
//       strokeWeight(0.0);
       noStroke();
       //stroke(0,0,255,100);
       fill(255,255,10,100);

//       stroke(0,100,100,40);
       //line(padding+horizontalDivision*((12*i)+j), verticalSquareSize-padding, padding+horizontalDivision*((12*i)+j), transactionsPerMonth[i][j]*SPL_Multiplier+verticalSquareSize-padding);
       ellipse(padding+horizontalDivision*((12*i)+j)-8, height-transactionsPerMonth[i][j]*SPL_Multiplier-verticalSquareSize-padding, SPL_Circle_Multiplier*sqrt(transactionsPerMonth[i][j]), SPL_Circle_Multiplier*sqrt(transactionsPerMonth[i][j]));
       
       //NYtimes line
       //stroke(255,0,0,100);
       fill(0,0,100,100);
//       fill(0,0,100,40);
//       line(padding+horizontalDivision*((12*i)+j)+2, verticalSquareSize-padding, padding+horizontalDivision*((12*i)+j)+2, articlesPerMonth[i][j]*NYT_Multiplier+verticalSquareSize-padding);
       ellipse(padding+horizontalDivision*((12*i)+j)-8, height-articlesPerMonth[i][j]*NYT_Multiplier-verticalSquareSize-padding, NYT_Circle_Multiplier*sqrt(articlesPerMonth[i][j]), NYT_Circle_Multiplier*sqrt(articlesPerMonth[i][j]));

       //Circle for amount of front page articles
       fill(30,130,20,120);//
       ellipse(padding+horizontalDivision*((12*i)+j)-8, height-articlesPerMonth[i][j]*NYT_Multiplier-verticalSquareSize-padding, NYT_Circle_Multiplier*sqrt(frontPagePerMonth[i][j]),NYT_Circle_Multiplier*sqrt(frontPagePerMonth[i][j]));

       //draw the year labels every 12 months
       if(j==0){
         textFont(font1);
         fill(100,10,160);
         textAlign(LEFT,TOP);
         text(2006+i,padding+horizontalDivision*((12*i)+j)-8,height-padding);
       }
       
       //rollover for new york times article titles
       if(abs(mouseX-(padding+horizontalDivision*((12*i)+j)))<7){
         textAlign(LEFT,BOTTOM);
         fill(0,0,100,60);
         text("Front Page Article:",padding, verticalSquareSize*2+padding);
         text(articleTitles[i][j],padding, verticalSquareSize*2+padding+30);
       }
    }
  }
  
  //draw title and labels
  textFont(font1);
  
  fill(255,255,10,100);
  textAlign(LEFT,BOTTOM);
  text("Seattle Public Library", padding, padding+10);
  text("Transaction Titles Containing 'Real Estate'", padding, padding+25);
  
  fill(0,0,100,100);//
  textAlign(LEFT,BOTTOM);
  text("New York Times", padding, padding+40);
  text("Articles Containing 'Greece'", padding, padding+55);
  
  fill(30,130,20,120);//
  textSize(16);
  textAlign(LEFT,BOTTOM);
//  text("Front Page Article Count", padding, padding+70);
}

void drawGrid(){
  //draw horizontal grid
  stroke(0,0,70);
  strokeWeight(0.5);
/*
i:for from 0-5
       //draw the year labels every 12 months
       if(j==0){
         textFont(font1);
         fill(100,10,160);
         textAlign(LEFT,TOP);
         text(2006+i,padding+horizontalDivision*((12*i)+j),height-padding);
       }
*/
  for(int i = 0;i<=5;i++){  // used to be for: horiz grid divisions
    line(padding+15*(12*i)+12,0,padding+15*(12*i)+12, height);
//    line(i*horizontalSquareSize+padding,0,i*horizontalSquareSize+padding, height);
  }
  //draw vertical grid
  stroke(0,0,70);
  strokeWeight(0.5);
  for(int i = 0;i<=verticalGridDivisions;i++){
    line(0,i*verticalSquareSize-padding,width, i*verticalSquareSize-padding);
//    line(0,i*verticalSquareSize+padding,width, i*verticalSquareSize+padding);
  }
}

//controls
void keyPressed(){
 //press spacebar to toggle the grid on and off  
 if(key == ' '){
  showGrid = !showGrid;
 }
}

